==> fetch.php?media=download_software:mae3xx:mae320_rootfs_trusty_v2_4_1.tar.xz: opt/mae3xx/app/AppServer/Handlers/Warplink.py <==
# -*- coding: utf-8 -*-
from Handlers import BaseHandler

#-------------------------------------------------------------------------------
#
#-------------------------------------------------------------------------------
class Warplink(BaseHandler.BaseHandler):
	#=======================================================
	# 
	#=======================================================
	def __init__(self):
		self.config = "/etc/ddclient.conf"
		self.default = "/etc/default/ddclient"
		self.name = 'Warplink'
	#=======================================================
	# 
	#=======================================================
	def Get(self, request):

		status = 200
		"""
		result={}
		type = request.query.type
		if type == 'config':
			result = self.readConfig()
		elif type == 'status':
		"""
		result = self.readConfig()
		return result, status

	#=======================================================
	# 
	#=======================================================
	def Put(self, request):

		status = 200
		self.writeConfig(request.json)

		return status
	#=======================================================
	# 
	#=======================================================
	def readConfig(self):

		conf = {'ddns':{'start':'no', 'userid':'', 'password':'' }}

		fd = open(self.config, "r")
		warplink = False
		for line in fd:
			if line.startswith('server'):
				sline = line.strip('\n').split('=')
				if sline[1] == 'www.warplink.ne.jp':
					warplink = True
				else:
					warplink = False
			elif line.startswith('login') and warplink:
				sline = line.strip('\n').split('=')
				conf['ddns']['userid'] = sline[1]
			elif line.startswith('password')and warplink:
				sline = line.strip('\n').split('=')
				conf['ddns']['password'] = sline[1]
		fd.close()
		
		fd = open(self.default, "r")
		for line in fd:
			if line.startswith('run_daemon'):
				sline = line.strip('\n').split('=')
				if 'true' in sline[1]:
					conf['ddns']['start'] = 'yes'
		fd.close()
		return conf

	#=======================================================
	# 
	#=======================================================
	def writeConfig(self, args):

		config = []
		fd = open(self.config, "r")
		warplink = False
		for line in fd:
			if line.startswith('server'):
				sline = line.strip('\n').split('=')
				if sline[1] == 'www.warplink.ne.jp':
					warplink = True
				else:
					warplink = False
				config.append(line.strip('\n'))
			elif line.startswith('login') and warplink:
				config.append('login=%s' % args['ddns']['userid'])
			elif line.startswith('password')and warplink:
				config.append('password=%s' % args['ddns']['password'])
			else:
				config.append(line.strip('\n'))
		fd.close()
		fd = open(self.config, "w")
		fd.write('\n'.join(config))
		fd.close()

		default = []
		fd = open(self.default, "r")
		for line in fd:
			if line.startswith('run_daemon'):
				if args['ddns']['start'] == 'yes':
					default.append('run_daemon="true"')
				else:
					default.append('run_daemon="false"')
			else:
				default.append(line.strip('\n'))
		fd.close()
		fd = open(self.default, "w")
		fd.write('\n'.join(default))
		fd.close()

		if args['ddns']['start'] == 'yes':
			action = 'restart'
		else:
			action = 'stop'
		self.service('ddclient', action)

==> fetch.php?media=download_software:mae3xx:mae320_rootfs_trusty_v2_7_0.tar.xz: opt/mae3xx/app/AppServer/Handlers/Warplink.py <==
# -*- coding: utf-8 -*-
from Handlers import BaseHandler

#-------------------------------------------------------------------------------
#
#-------------------------------------------------------------------------------
class Warplink(BaseHandler.BaseHandler):
	#=======================================================
	# 
	#=======================================================
	def __init__(self):
		self.config = "/etc/ddclient.conf"
		self.default = "/etc/default/ddclient"
		self.name = 'Warplink'
	#=======================================================
	# 
	#=======================================================
	def Get(self, request):

		status = 200
		"""
		result={}
		type = request.query.type
		if type == 'config':
			result = self.readConfig()
		elif type == 'status':
		"""
		result = self.readConfig()
		return result, status

	#=======================================================
	# 
	#=======================================================
	def Put(self, request):

		status = 200
		self.writeConfig(request.json)

		return status
	#=======================================================
	# 
	#=======================================================
	def readConfig(self):

		conf = {'ddns':{'start':'no', 'userid':'', 'password':'' }}

		fd = open(self.config, "r")
		warplink = False
		for line in fd:
			if line.startswith('server'):
				sline = line.strip('\n').split('=')
				if sline[1] == 'www.warplink.ne.jp':
					warplink = True
				else:
					warplink = False
			elif line.startswith('login') and warplink:
				sline = line.strip('\n').split('=')
				conf['ddns']['userid'] = sline[1]
			elif line.startswith('password')and warplink:
				sline = line.strip('\n').split('=')
				conf['ddns']['password'] = sline[1]
		fd.close()
		
		fd = open(self.default, "r")
		for line in fd:
			if line.startswith('run_daemon'):
				sline = line.strip('\n').split('=')
				if 'true' in sline[1]:
					conf['ddns']['start'] = 'yes'
		fd.close()
		return conf

	#=======================================================
	# 
	#=======================================================
	def writeConfig(self, args):

		config = []
		fd = open(self.config, "r")
		warplink = False
		for line in fd:
			if line.startswith('server'):
				sline = line.strip('\n').split('=')
				if sline[1] == 'www.warplink.ne.jp':
					warplink = True
				else:
					warplink = False
				config.append(line.strip('\n'))
			elif line.startswith('login') and warplink:
				config.append('login=%s' % args['ddns']['userid'])
			elif line.startswith('password')and warplink:
				config.append('password=%s' % args['ddns']['password'])
			else:
				config.append(line.strip('\n'))
		fd.close()
		fd = open(self.config, "w")
		fd.write('\n'.join(config))
		fd.close()

		if args['ddns']['start'] == 'yes':
			self._writeDefalut(True)
			self.service('ddclient', 'restart')
		else:
			self.service('ddclient', 'stop')
			self._writeDefalut(False)
		
	#=======================================================
	# 
	#=======================================================
	def _writeDefalut(self, daemon):

		default = []
		fd = open(self.default, "r")
		for line in fd:
			if line.startswith('run_daemon'):
				if daemon:
					default.append('run_daemon="true"')
				else:
					default.append('run_daemon="false"')
			else:
				default.append(line.strip('\n'))
		fd.close()
		fd = open(self.default, "w")
		fd.write('\n'.join(default))
		fd.close()
